@@ -1,7 +1,7 @@
 /*
  * PSD Estimation and whitener
  *
- * Copyright (C) 2008  Chad Hanna, Kipp Cannon
+ * Copyright (C) 2008--2014  Chad Hanna, Kipp Cannon
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,6 +28,7 @@
 #include <gstlal/gstaudioadapter.h>
 
 
+#include <lal/FrequencySeries.h>
 #include <lal/LALDatatypes.h>
 #include <lal/TimeFreqFFT.h>
 #include <lal/Units.h>
@@ -88,6 +89,7 @@ struct _GSTLALWhiten {
 	 */
 
 	LALUnit sample_units;
+	gchar *instrument;
 	gint sample_rate;
 
 	GstAudioAdapter *input_queue;
@@ -147,6 +149,7 @@ struct _GSTLALWhiten {
 
 /**
  * GSTLALWhitenClass:
+ * @parent_class:  the parent class
  */
 
 
@@ -158,6 +161,19 @@ struct _GSTLALWhitenClass {
 GType gstlal_whiten_get_type(void);
 
 
+/*
+ * ============================================================================
+ *
+ *                                Exported API
+ *
+ * ============================================================================
+ */
+
+
+GstMessage *gstlal_whiten_message_psd_new(GSTLALWhiten *element, const gchar *instrument, const REAL8FrequencySeries *psd);
+REAL8FrequencySeries *gstlal_whiten_message_psd_parse(GstMessage *m);
+
+
 G_END_DECLS
 
 
